aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/ShowCopyDialog.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/ui/ShowCopyDialog.h (renamed from include/ui/ShowCopyDialog.h)30
1 files changed, 17 insertions, 13 deletions
diff --git a/include/ui/ShowCopyDialog.h b/src/ui/ShowCopyDialog.h
index 45b06e2d..fefef7ab 100644
--- a/include/ui/ShowCopyDialog.h
+++ b/src/ui/ShowCopyDialog.h
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -25,22 +25,26 @@
#ifndef GPGFRONTEND_ZH_CN_TS_SHOWCOPYDIALOG_H
#define GPGFRONTEND_ZH_CN_TS_SHOWCOPYDIALOG_H
-#include "GpgFrontend.h"
+#include "ui/GpgFrontendUI.h"
+
+namespace GpgFrontend::UI {
class ShowCopyDialog : public QDialog {
-Q_OBJECT
-public:
- explicit ShowCopyDialog(const QString &text, const QString &info = "", QWidget *parent = nullptr);
+ Q_OBJECT
+ public:
+ explicit ShowCopyDialog(const QString& text, const QString& info = "",
+ QWidget* parent = nullptr);
-private slots:
+ private slots:
- void slotCopyText();
+ void slotCopyText();
-private:
- QLabel *infoLabel;
- QTextEdit *textEdit;
- QPushButton *copyButton;
+ private:
+ QLabel* infoLabel;
+ QTextEdit* textEdit;
+ QPushButton* copyButton;
};
+} // namespace GpgFrontend::UI
-#endif //GPGFRONTEND_ZH_CN_TS_SHOWCOPYDIALOG_H
+#endif // GPGFRONTEND_ZH_CN_TS_SHOWCOPYDIALOG_H
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or